@@ -3,17 +3,11 @@ module.exports = {
     "logDir":       "/var/log/nps",
     "log": {
         "appenders": {
-            "consoleappender": {
-                "type": "console",
-                "layout": {
-                    "type": "pattern",
-                    "pattern": "[%d] [%p] %c - %m"
-                }
-            }
+            "console": { "type": "console", "pattern": "[%d] [%p] %c - %m" },
         },
         "categories": {
             "default": {
-                "appenders":["consoleappender"],
+                "appenders": ["console"],
                 "level": "INFO"     // Log Levels are DEBUG, INFO, WARN and ERROR
             }
         },
